@@ -16,7 +16,7 @@
 if {[info commands package] == ""} {
     error "version mismatch: library\nscripts expect Tcl version 7.5b1 or later but the loaded version is\nonly [info patchlevel]"
 }
-package require -exact Tcl 8.6.2
+package require -exact Tcl 8.6.4
 
 # Compute the auto path to use in this interpreter.
 # The values on the path come from several locations:
@@ -52,14 +52,16 @@ namespace eval tcl {
 	    lappend ::auto_path $Dir
 	}
     }
-# OpenBSD layout
-if {0} {
+
+# OpenBSD layout.
+# Tcl extensions shouldn't be installed in /usr/local/lib.
+# Don't add /usr/local/lib to the auto_path.
+
     set Dir [file join [file dirname [file dirname \
 	    [info nameofexecutable]]] lib]
-    if {$Dir ni $::auto_path} {
+    if {$Dir ne {/usr/local/lib} && $Dir ni $::auto_path} {
 	lappend ::auto_path $Dir
     }
-}
     catch {
 	foreach Dir $::tcl_pkgPath {
 	    if {$Dir ni $::auto_path} {
