@@ -318,11 +318,9 @@ proc ::tcl::tm::Defaults {} {
     # something other than [::list] in this namespace.
 
     # OpenBSD layout
-    foreach dir [::list [info library] [file dirname [info library]]] {
-	foreach ver [::list [info tclversion] 8.5] {
-	    add [file join $dir modules $ver]
-	}
-    }
+    add [file join [info library] modules] \
+	[file join [lindex $::tcl_pkgPath 0] modules 86] \
+	[file join [lindex $::tcl_pkgPath 0] modules 85]
 
     if {$tcl_platform(platform) eq "windows"} {
 	set sep ";"
